@@ -7,6 +7,7 @@ from .load_data.data_source import DataSourcePanel
 from .transform.transform_action_ui import (
     FilterPanelView,
     GroupByPanelView,
+    MergePanelView,
     SelectColumnsPanelView,
 )
 
@@ -16,6 +17,7 @@ _ui_for_action = {
     action.ActionSelectColumns: SelectColumnsPanelView,
     action.ActionDropColumns: SelectColumnsPanelView,
     action.ActionGroupBy: GroupByPanelView,
+    action.ActionMerge: MergePanelView,
 }
 
 
