@@ -3,7 +3,7 @@ import os
 import textwrap
 import traceback
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Optional, cast
+from typing import Any, Callable, Dict, Optional, cast
 
 import ipyvuetify as vy
 import ipywidgets
@@ -490,7 +490,6 @@ def AssistantMain():
 
     snippet_saved_count, set_snippet_saved_count = reacton.use_state(0)
     snippet_edit_mode, set_snippet_edit_mode = reacton.use_state(False)
-    writable_paths, set_writable_paths = reacton.use_state(cast(Optional[List[str]], None))
 
     snippet_add_header, set_snippet_add_header = reacton.use_state(cast(Optional[str], None))
     add_dialog_open, set_add_dialog_open = reacton.use_state(False)
@@ -523,7 +522,7 @@ def AssistantMain():
             )
 
     reacton.use_memo(on_selected, [selected])
-    reacton.use_memo(lambda: set_writable_paths(snippets.get_writable_paths()), [])
+    writable_paths = reacton.use_memo(snippets.get_writable_paths, [])
 
     overwrite = bool(code_up is not None and code_up["code"].strip())
 
